/*
 * This file is part of FGGL.
 *
 * FGGL is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * FGGL is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with FGGL.
 * If not, see <https://www.gnu.org/licenses/>.
 */

//
// Created by webpigeon on 03/09/22.
//

#ifndef FGGL_GFX_PALLETS_HPP
#define FGGL_GFX_PALLETS_HPP

#include "fggl/gfx/paint.hpp"

namespace fggl::gfx::pallets {

	// VGA pallet
	namespace vga {
		constexpr math::vec3 WHITE{1.0F, 1.0F, 1.0F};
		constexpr math::vec3 SILVER{0.75F, 0.75F, 0.75F};
		constexpr math::vec3 GRAY{0.5F, 0.5F, 0.5F};
		constexpr math::vec3 BLACK{0.0F, 0.0F, 0.0F};
		constexpr math::vec3 RED{1.0F, 0.0F, 0.0F};
		constexpr math::vec3 MAROON{0.5F, 0.0F, 0.0F};
		constexpr math::vec3 YELLOW{1.0F, 1.0F, 0.0F};
		constexpr math::vec3 OLIVE{0.5F, 0.5F, 0.0F};
		constexpr math::vec3 LIME{0.0F, 1.0F, 0.0F};
		constexpr math::vec3 GREEN{0.0F, 0.5F, 0.0F};
		constexpr math::vec3 AQUA{0.0F, 1.0F, 1.0F};
		constexpr math::vec3 TEAL{0.0F, 0.5F, 0.5F};
		constexpr math::vec3 BLUE{0.0F, 0.0F, 1.0F};
		constexpr math::vec3 NAVY{0.0F, 0.0F, 0.5F};
		constexpr math::vec3 FUCHSIA{1.0F, 0.0F, 1.0F};
		constexpr math::vec3 PURPLE{0.5F, 0.0F, 0.5F};
	}

	// Tango Free Desktop Pallet
	namespace tango {
		constexpr auto BUTTER_0 = rgb(0xFCE94F);
		constexpr auto BUTTER_1 = rgb(0xEDD400);
		constexpr auto BUTTER_2 = rgb(0xC4A000);

		constexpr auto ORANGE_0 = rgb(0xFCAF3E);
		constexpr auto ORANGE_1 = rgb(0xF57900);
		constexpr auto ORANGE_2 = rgb(0xCE5C00);

		constexpr auto CHOCOLATE_0 = rgb(0xE9B96E);
		constexpr auto CHOCOLATE_1 = rgb(0xC17D11);
		constexpr auto CHOCOLATE_2 = rgb(0x8F5902);

		constexpr auto CHAMELEON_0 = rgb(0x8AE234);
		constexpr auto CHAMELEON_1 = rgb(0x73D216);
		constexpr auto CHAMELEON_2 = rgb(0x4E9a06);

		constexpr auto SKY_BLUE_0 = rgb(0x729FCF);
		constexpr auto SKY_BLUE_1 = rgb(0x3456A4);
		constexpr auto SKY_BLUE_2 = rgb(0x204A87);

		constexpr auto PLUM_0 = rgb(0xAD7FA8);
		constexpr auto PLUM_1 = rgb(0x75507B);
		constexpr auto PLUM_2 = rgb(0x5C3566);

		constexpr auto SCARLET_RED_0 = rgb(0xEF2929);
		constexpr auto SCARLET_RED_1 = rgb(0xCC0000);
		constexpr auto SCARLET_RED_2 = rgb(0xA40000);

		constexpr auto ALUMINIUM_0 = rgb(0xEEEEEC);
		constexpr auto ALUMINIUM_1 = rgb(0xD3D7CF);
		constexpr auto ALUMINIUM_2 = rgb(0xBABDB6);
		constexpr auto ALUMINIUM_3 = rgb(0x888a85);
		constexpr auto ALUMINIUM_4 = rgb(0x555753);
		constexpr auto ALUMINIUM_6 = rgb(0x2e3436);
	}

	// solarized
	namespace solarized {
		// backgrounds (dark)
		constexpr auto BASE03 = rgb(0x002B36);
		constexpr auto BASE02 = rgb(0x073642);

		// content tones
		constexpr auto BASE01 = rgb(0x586E75);
		constexpr auto BASE00 = rgb(0x657B83);
		constexpr auto BASE0 = rgb(0x839496);
		constexpr auto BASE1  = rgb(0X93A1A1);

		// backgrounds (light)
		constexpr auto BASE2 = rgb(0xEEE8D5);
		constexpr auto BASE3 = rgb(0xFDF6E3);

		// accent colours
		constexpr auto YELLOW = rgb(0xB58900);
		constexpr auto ORANGE = rgb(0xCB4B16);
		constexpr auto RED = rgb(0xDC322F);
		constexpr auto MAGENTA = rgb(0xD33682);
		constexpr auto VIOLET = rgb(0x6C71C4);
		constexpr auto BLUE = rgb(0x268bd2);
		constexpr auto CYAN = rgb(0x2AA198);
		constexpr auto GREEN = rgb(0x859900);
	}

} // namespace fggl::gfx::pallets

#endif //FGGL_GFX_PALLETS_HPP
